# @visa/charts-python

This package bundles [visa chart components](../../) web components for use in [pyvisacharts](../). We leverage [stencil's component distribution](https://stenciljs.com/docs/custom-elements) in the creation of @visa/charts-python.

---

### Installation Steps

- Using npm
  ```
  $ npm i @visa/charts-python
  ```
- Using yarn
  ```
  $ yarn add @visa/charts-python
  ```

**Note:** This package has been created specifically for use in [pyvisacharts](../), use of this code outside of [pyvisacharts](../) is not recommended or supported.

---

#### Components with `Ready` status in this bundle

- [@visa/bar-chart](../bar-chart)
- [@visa/clustered-bar-chart](../clustered-bar-chart)
- [@visa/stacked-bar-chart](../stacked-bar-chart)
- [@visa/line-chart](../line-chart)
- [@visa/pie-chart](../pie-chart)
- [@visa/scatter-plot](../scatter-plot)
- [@visa/heat-map](../heat-map)
- [@visa/circle-packing](../circle-packing)
- [@visa/parallel-plot](../parallel-plot)
- [@visa/dumbbell-plot](../dumbbell-plot)
- [@visa/world-map](../world-map)
- [@visa/alluvial-diagram](../alluvial-diagram)
- [@visa/visa-charts-data-table](../data-table)
- [@visa/keyboard-instructions](packages/keyboard-instructions)

<!-- #### Components with `Development` status -->
<hr>
